import QtQuick 1.1
import com.nokia.meego 1.0
import QtMultimediaKit 1.1
import QtMobility.feedback 1.1
import CamDisplay 1.0
import Settings 1.0

Page {
    orientationLock: PageOrientation.LockLandscape

    onStatusChanged: {
        if(status == PageStatus.Active)
        {
            cd.visible = true;
            cd.startLoop(true);
        }
        else
        {
            cd.startLoop(false);
            cd.visible = false;
        }
    }

    function showResult(result) {
        var component = Qt.createComponent("ResultPage.qml");
        if (component.status == Component.Ready)
            pageStack.push(component, {resultRaw: result, fromHistory: false});
        else
            console.log("Error loading component:", component.errorString());
    }

    function showSettings() {
        var component = Qt.createComponent("SettingsPage.qml")
        if (component.status == Component.Ready)
            pageStack.push(component);
        else
            console.log("Error loading component:", component.errorString());
    }

    SoundEffect {
        id: beep
        source: "file:///usr/share/themes/base/meegotouch/feedbacks/priority1_nfc_touch/audio.wav"
    }

    Settings {
        id: settings
    }

    CamDisplay {
        id: cd
        anchors.fill: parent
        onSuccess: {
            visible = false;
            if (settings.sound) beep.play();
            showResult(result);
        }
    }

    ButtonStyle {
        id: bs1
        background: ""
        checkedBackground: ""
        pressedBackground: "qrc:///Button_pressed.png"
        buttonHeight: 64
        buttonWidth: 64
    }

    ButtonStyle {
        id: bs2
        background: "qrc:///Button_off.png"
        checkedBackground: "qrc:///Button_on.png"
        pressedBackground: "qrc:///Button_pressed.png"
        buttonHeight: 64
        buttonWidth: 64
    }

    Button {
        id: settingsB
        iconSource: "image://theme/icon-m-toolbar-settings-selected"
        platformStyle: bs2
        x:8; y:408;
        onClicked: { cd.visible = false; showSettings(); }
    }

    Button {
        id: torchB
        iconSource: checked ? "image://theme/icon-m-camera-torch-on" :  "image://theme/icon-m-camera-torch-off"
        platformStyle: bs2
        x:8; y:208;
        checkable: true;
        checked: false;
        onCheckedChanged: { cd.setTorch(checked); }
    }

    Button {
        id: barB
        iconSource: checked ? "qrc:///Button_BC_on.png" : "qrc:///Button_BC_off.png"
        platformStyle: bs1
        x:782; y:192;
        checkable: true
        onCheckedChanged: {
            if (checked)
            {
                cd.setDecode(508);
                aztecB.checked = false;
                dmB.checked = false;
                qrB.checked = false;
                enabled = false;
            }
            else
                enabled = true;
        }
    }

    Button {
        id: aztecB
        iconSource: checked ? "qrc:///Button_AC_on.png" : "qrc:///Button_AC_off.png"
        platformStyle: bs1
        x:782; y:264;
        checkable: true
        onCheckedChanged: {
            if (checked)
            {
                cd.setDecode(512);
                barB.checked = false;
                dmB.checked = false;
                qrB.checked = false;
                enabled = false;
            }
            else
                enabled = true;
        }
    }

    Button {
        id: dmB
        iconSource: checked ? "qrc:///Button_DM_on.png" : "qrc:///Button_DM_off.png"
        platformStyle: bs1
        x:782; y:336;
        checkable: true
        onCheckedChanged: {
            if (checked)
            {
                cd.setDecode(2);
                barB.checked = false;
                aztecB.checked = false;
                qrB.checked = false;
                enabled = false;
            }
            else
                enabled = true;
        }
    }

    Button {
        id: qrB
        iconSource: checked ? "qrc:///Button_QR_on.png" : "qrc:///Button_QR_off.png"
        platformStyle: bs1
        x:782; y:408;
        checkable: true
        checked: true
        onCheckedChanged: {
            if (checked)
            {
                cd.setDecode(1);
                barB.checked = false;
                aztecB.checked = false;
                dmB.checked = false;
                enabled = false;
            }
            else
                enabled = true;
        }
    }
}
