import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import Result 1.0

Page {
    property string resultRaw
    property bool fromHistory

    function showSettings() {
        var component = Qt.createComponent("SettingsPage.qml")
        if (component.status == Component.Ready)
            pageStack.push(component);
        else
            console.log("Error loading component:", component.errorString());
    }

    id: resultPage
    tools: resultTools

    Result {
        id: res
    }

    Component.onCompleted: {
        res.process(resultRaw);
    }

    ButtonStyle {
        id: tbb
        buttonWidth: 64
        buttonHeight: 64
        background: ""
    }

    ButtonStyle {
        id: bs
        background: "qrc:///Button_off.png"
        checkedBackground: "qrc:///Button_on.png"
        pressedBackground: "qrc:///Button_pressed.png"
        buttonHeight: 64
        buttonWidth: 64
    }

    ToolBar {
        id: resultTools
        visible: true
        tools: ToolBarLayout {
            ToolIcon {
                iconId: "toolbar-back";
                onClicked: { pageStack.pop(); }
            }
            ToolButton {
                iconSource: "qrc:///copy.png"
                platformStyle: tbb
                onClicked: { res.copy(); ib.show(); }
            }
            ToolIcon {
                iconId: "toolbar-search";
                onClicked: { res.search(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-browser-main-view"
                visible: res.typeName=="URL"
                platformStyle: tbb
                onClicked: { res.defaultAction(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-contacts-main-view"
                visible: res.typeName=="Telephone Number"
                platformStyle: tbb
                onClicked: { res.defaultAction(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-telephony-main-view"
                visible: res.typeName=="Telephone Number"
                platformStyle: tbb
                onClicked: { res.call(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-maps-main-view"
                visible: res.typeName=="Geo Coordinates"
                platformStyle: tbb
                onClicked: { res.defaultAction(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-browser-main-view"
                visible: res.typeName=="Bookmark"
                platformStyle: tbb
                onClicked: { res.bookmark(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-calendar-main-view"
                visible: res.typeName=="vCalendar Entry"
                platformStyle: tbb
                onClicked: { res.openCal(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-contacts-main-view"
                visible: res.typeName=="meCard Contact"
                platformStyle: tbb
                onClicked: { res.openMeCard(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-contacts-main-view"
                visible: res.typeName=="vCard Contact"
                platformStyle: tbb
                onClicked: { res.openVCard(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-conversation-main-view"
                visible: res.typeName=="Text Message"
                platformStyle: tbb
                onClicked: { res.sms(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-email-main-view"
                visible: res.typeName=="E-mail Message"
                platformStyle: tbb
                onClicked: { res.smtp(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-email-main-view"
                visible: res.typeName=="E-mail (MATMSG)"
                platformStyle: tbb
                onClicked: { res.matmsg(); }
            }
            ToolButton {
                iconSource: "image://theme/icon-l-email-main-view"
                visible: res.typeName=="E-mail Address"
                platformStyle: tbb
                onClicked: { res.mailto(); }
            }
            ToolButton {
                iconSource: "qrc:///icon-wlan.png"
                visible: res.typeName=="Wi-Fi Access Point"
                platformStyle: tbb
                onClicked: { res.wifi(); ib2.show(); }
            }
            ToolIcon {
                iconId: "toolbar-settings";
                onClicked: { showSettings(); }
            }
        }
    }

    Image {
        id: icon
        source: res.icon
        anchors.topMargin: 12
        anchors.bottomMargin: 12
        anchors.leftMargin: 15
        anchors.top: parent.top
        anchors.left: parent.left
    }

    Text {
        id: lc
        text: res.typeName
        font.family: "Nokia Pure Text Light"
        font.pixelSize: 32
        font.weight: Font.Light
        color: "white"
        anchors.topMargin: 20
        anchors.bottomMargin: 30
        anchors.leftMargin: 15
        anchors.verticalCenter: icon.verticalCenter
        anchors.left: icon.right
    }

    Button {
        id: showRaw
        platformStyle: bs
        text: "RAW"
        checkable: true
        font.family: "Nokia Pure Text"
        font.weight: Font.Normal
        font.pixelSize: 18
        anchors.rightMargin: 15
        anchors.verticalCenter: icon.verticalCenter
        anchors.right: parent.right
        visible: res.parseable
        onCheckedChanged: {
            if (checked) {
                content.visible = false;
                sd.visible = false;
                contentPlain.visible = true;
                sdPlain.visible = true;
            }
            else {
                content.visible = true;
                sd.visible = true;
                contentPlain.visible = false;
                sdPlain.visible = false;
            }
        }
    }

    Image {
        id: sep
        source: "/usr/share/themes/blanco/meegotouch/images/theme/basement/meegotouch-separator/meegotouch-separator-inverted-background-horizontal.png"
        height: 2
        width: parent.width - 30
        anchors.margins: 15
        anchors.topMargin: 12
        anchors.top: icon.bottom
        anchors.left: parent.left
    }

    ListView {
        id: content
        model: mdlResult
        width: parent.width - 15
        anchors.margins: 15
        anchors.top: sep.bottom
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        clip: true
        visible: res.parseable

        delegate: ListDelegate{
            Text {
                id: mainText
                text: field; color: "#BED600";
                font.family: "Nokia Pure Text"; font.pixelSize: 20; font.weight: Font.Normal
                y: 10
                visible: {field != ""}
            }
            Text {
                id: subText
                text: mods; color: "#AAAAAA";
                font.family: "Nokia Pure Text"; font.pixelSize: 16; font.weight: Font.Normal
                y: 12; anchors.right: parent.right;
                visible: {mods != ""}
            }
            Text {
                id: tv
                text: name; color: "white"; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                font.family: "Nokia Pure Text"; font.pixelSize: 28; font.weight: Font.Normal
                anchors.top: mainText.bottom; width: parent.width
                visible: {name != ""}
            }
            Image {
                id: div
                source: "/usr/share/themes/blanco/meegotouch/images/theme/basement/meegotouch-separator/meegotouch-separator-inverted-background-horizontal.png"
                height: 2
                opacity: 0.25
                width: parent.width
                anchors.top: tv.bottom; anchors.topMargin: 7;
            }
            height: div.y+2; width: content.width - 15
            onClicked: {
                if(field.toUpperCase().search("TEL") != -1)
                {
                    menuTitleTel.text = name;
                    menuTel.open();
                }
                else if(name.search("([mM][aA][iI][lL][tT][oO]:)?[a-zA-Z0-9_!#$%&amp;'*+/=?^`{|}~-]+(\.[a-zA-Z0-9_!#$%&amp;'*+/=?^`{|}~-]+)*@([a-zA-Z0-9_-]+\.)+[a-zA-Z0-9_-]+") != -1)
                {
                    menuTitleMail.text = name;
                    menuMail.open();
                }
                else if((field.toUpperCase().search("URL") != -1) || res.isURL(name))
                {
                    menuTitleUrl.text = name;
                    menuUrl.open();
                }
                else
                {
                    menuTitle.text = name;
                    menu.open();
                }
            }
        }
    }

    Menu {
        id: menu
        title: [ Text {
                x:20; y:11;
                id: menuTitle
                font.family: "Nokia Pure Text"; font.pixelSize: 24; font.weight: Font.Bold
                color: "#BED600"; width:parent.width-40; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            } ]
        MenuLayout {
            MenuItem {
                text:"Copy"
                onClicked: { res.copy(menuTitle.text); ib.show(); }
            }
            MenuItem {
                text:"Search"
                onClicked: res.search(menuTitle.text)
            }
        }
    }

    Menu {
        id: menuTel
        title: [ Text {
                x:20; y:11;
                id: menuTitleTel
                font.family: "Nokia Pure Text"; font.pixelSize: 24; font.weight: Font.Bold
                color: "#BED600"; width:parent.width-40; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            } ]
        MenuLayout {
            MenuItem {
                text:"Call"
                onClicked: { res.call(menuTitleTel.text); }
            }
            MenuItem {
                text:"Compose SMS"
                onClicked: { res.sms(menuTitleTel.text); }
            }
            MenuItem {
                text:"Copy"
                onClicked: { res.copy(menuTitleTel.text); ib.show(); }
            }
            MenuItem {
                text:"Search"
                onClicked: res.search(menuTitleTel.text)
            }
        }
    }

    Menu {
        id: menuMail
        title: [ Text {
                x:20; y:11;
                id: menuTitleMail
                font.family: "Nokia Pure Text"; font.pixelSize: 24; font.weight: Font.Bold
                color: "#BED600"; width:parent.width-40; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            } ]
        MenuLayout {
            MenuItem {
                text:"Compose E-mail"
                onClicked: {
                    res.mailto(menuTitleMail.text);
                }
            }
            MenuItem {
                text:"Copy"
                onClicked: { res.copy(menuTitleMail.text); ib.show(); }
            }
            MenuItem {
                text:"Search"
                onClicked: res.search(menuTitleMail.text)
            }
        }
    }


    Menu {
        id: menuUrl
        title: [ Text {
                x:20; y:11;
                id: menuTitleUrl
                font.family: "Nokia Pure Text"; font.pixelSize: 24; font.weight: Font.Bold
                color: "#BED600"; width:parent.width-40; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            } ]
        MenuLayout {
            MenuItem {
                text:"Go to URL"
                onClicked: { res.defaultAction(menuTitleUrl.text); }
            }
            MenuItem {
                text:"Copy"
                onClicked: { res.copy(menuTitleUrl.text); ib.show(); }
            }
            MenuItem {
                text:"Search"
                onClicked: res.search(menuTitleUrl.text)
            }
        }
    }

    ScrollDecorator {
        id: sd
        flickableItem: content
        visible: res.parseable
    }

    Flickable {
        id: contentPlain
        width: parent.width
        anchors.top: sep.bottom
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        visible: !res.parseable
        clip: true
        contentHeight: txt.implicitHeight

        Text {
            id: txt
            anchors.fill: parent; anchors.margins: 15; textFormat: Text.RichText
            text: res.rawFormatted; color: "white"; wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            font.family: "Nokia Pure Text"; font.pixelSize: 28; font.weight: Font.Normal
            onLinkActivated: {res.defaultAction(link);}
        }
    }

    ScrollDecorator {
        id: sdPlain
        flickableItem: contentPlain
        visible: contentPlain.visible
    }

    InfoBanner {
        id: ib
        text: "Copied to clipboard"
        timerShowTime: 1500
    }

    InfoBanner {
        id: ib2
        text: "WLAN configuration added.\nYou may now select it"
        timerShowTime: 2700
    }

}
