import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import Settings 1.0

Page {
    id: settingsPage
    tools: settingsTools

    Settings {
        id: settings
    }

    Component.onCompleted: {
        lv.model.setProperty(0, "active", settings.sound);
        lv.model.setProperty(1, "subtitle", settings.search);
        lv.model.setProperty(2, "subtitle", settings.book);
        lv.model.setProperty(3, "subtitle", settings.geo);
    }

    ToolBar {
        id: settingsTools
        visible: true
        tools: ToolBarLayout {
            ToolIcon {
                iconId: "toolbar-back";
                onClicked: { pageStack.pop(); }
            }
        }
    }

    Text {
        id: lc
        text: "CodeCam Settings"
        font.family: "Nokia Pure Text Light"
        font.pixelSize: 32
        font.weight: Font.Light
        color: "white"
        anchors.topMargin: 20
        anchors.bottomMargin: 30
        anchors.leftMargin: 15
        anchors.top: parent.top
        anchors.left: parent.left
    }

    Image {
        id: sep
        source: "/usr/share/themes/blanco/meegotouch/images/theme/basement/meegotouch-separator/meegotouch-separator-inverted-background-horizontal.png"
        height: 2
        width: parent.width - 30
        anchors.margins: 15
        anchors.topMargin: 12
        anchors.top: lc.bottom
        anchors.left: parent.left
    }

    ListView {
        id: lv

        model: ListModel {
            ListElement {
                title: "Sound upon Scan"
                subtitle: ""
                active: false
                kind: 3
            }
            ListElement {
                title: "Web Search"
                subtitle: ""
                active: false
                kind: 1
            }
            ListElement {
                title: "ISBN Search"
                subtitle: ""
                active: false
                kind: 1
            }
            ListElement {
                title: "Geo Coordinates Search"
                subtitle: ""
                active: false
                kind: 1
            }
        }

        width: parent.width - 30
        anchors.margins: 15
        anchors.top: sep.bottom
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        clip: true

        delegate: ListDelegate {
            MouseArea {
                visible: kind != 1
                anchors.fill:parent
            }
            Image {
                source: "image://theme/icon-m-textinput-combobox-arrow"
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                visible: kind == 1
            }
            Switch {
                id: sw
                visible: kind == 2 || kind ==3
                platformStyle: SwitchStyle { switchOn: "qrc:///mint_switch.png" }
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                checked: model.active
            }
            MouseArea {
                anchors.fill: sw
                onClicked: {
                    if (title=="Sound upon Scan")
                        lv.model.setProperty(0, "active", settings.sound = !sw.checked);
                }
            }
            onClicked: { if (title == "Web Search") searchSD.open();
                else if (title == "ISBN Search") bookSD.open();
                else geoSD.open();
            }
        }
    }

    SelectionDialog {
        id: searchSD
        titleText: "Web Search"

        model: ListModel {
            ListElement { name: "Baidu" }
            ListElement { name: "Bing" }
            ListElement { name: "eBay" }
            ListElement { name: "Google" }
            ListElement { name: "Yandex" }
        }

        onSelectedIndexChanged: {
            settings.setSearch(model.get(selectedIndex).name);
            lv.model.setProperty(0, "subtitle", model.get(selectedIndex).name);
        }
    }

    SelectionDialog {
        id: bookSD
        titleText: "ISBN Search"

        model: ListModel {
            ListElement { name: "Amazon.com" }
            ListElement { name: "Amazon Canada" }
            ListElement { name: "Amazon China" }
            ListElement { name: "Amazon France" }
            ListElement { name: "Amazon Germany" }
            ListElement { name: "Amazon Italy" }
            ListElement { name: "Amazon Japan" }
            ListElement { name: "Amazon Spain" }
            ListElement { name: "Amazon UK" }
            ListElement { name: "eBay" }
            ListElement { name: "Google Books" }
        }

        onSelectedIndexChanged: {
            settings.setBook(model.get(selectedIndex).name);
            lv.model.setProperty(1, "subtitle", model.get(selectedIndex).name);
        }
    }

    SelectionDialog {
        id: geoSD
        titleText: "Geo Coordinates Search"

        model: ListModel {
            ListElement { name: "Google Maps" }
            ListElement { name: "Yandex Maps" }
        }

        onSelectedIndexChanged: {
            settings.setGeo(model.get(selectedIndex).name);
            lv.model.setProperty(2, "subtitle", model.get(selectedIndex).name);
        }
    }
}
